@@ -95,7 +95,6 @@ OC.L10N.register(
     "Delete share link" : "Dileu dolen rhannu",
     "Deleting share link …" : "Wrthi'n dileu dolen rhannu …",
     "An error occurred, unable to change the permission of the share." : "Bu gwall, ni fu modd newid caniatâd y gyfran.",
-    "can edit" : "yn gallu golygu",
     "Unshare with {displayName}" : "Dadrannu gyda {displayName}",
     "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
     "No users or groups" : "Dim defnyddwyr na grwpiau",
@@ -133,18 +132,8 @@ OC.L10N.register(
     "Delete edited event" : "Dileu digwyddiad wedi'i olygu",
     "or" : "neu",
     "No reminder" : "Dim nodyn atgoffa",
-    "CalDAV link copied to clipboard." : "Dolen CalDAV wedi'i chopïo i'r clipfwrdd.",
-    "CalDAV link could not be copied to clipboard." : "Nid oedd modd copïo dolen CalDAV i'r clipfwrdd.",
     "General" : "Cyffredinol",
-    "Personal availability settings" : "Gosodiadau argaeledd personol",
-    "Copy primary CalDAV address" : "Copïo prig gyfeiriad CalDAV",
-    "Copy iOS/macOS CalDAV address" : "Copïo cyfeiriad CalDAV iOS/macOS",
-    "Enable birthday calendar" : "Galluogi calendr pen-blwydd",
-    "Show tasks in calendar" : "Dangos tasgau yn y calendr",
-    "Show weekends" : "Dangos penwythnosau",
-    "Show week numbers" : "Dangos rhifau wythnosau",
     "Default reminder" : "Nodyn atgoffa rhagosodedig",
-    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} munud","{duration} funud","{duration} munud","{duration} munud"],
     "0 minutes" : "0 munud",
     "_{duration} hour_::_{duration} hours_" : ["{duration} awr","{duration} awr","{duration} awr","{duration} awr"],
@@ -234,8 +223,6 @@ OC.L10N.register(
     "Decline" : "Gwrthod",
     "Tentative" : "I'w gadarnhau",
     "No attendees yet" : "Dim mynychwyr eto",
-    "Successfully appended link to talk room to description." : "Llwyddwyd i atodi dolen i'r ystafell siarad i'r disgrifiad.",
-    "Error creating Talk room" : "Gwall wrth greu ystafell Siarad",
     "Attendees" : "Mynychwyr",
     "Remove attendee" : "Dileu mynychwr",
     "Chairperson" : "Cadeirydd",
@@ -398,7 +385,6 @@ OC.L10N.register(
     "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
     "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
     "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
-    "The visibility of this event in shared calendars." : "Gwelededd y digwyddiad hwn mewn calendrau a rennir.",
     "Add a location" : "Ychwanegu lleoliad",
     "Status" : "Statws",
     "Confirmed" : "Cadarnhawyd",
@@ -417,10 +403,24 @@ OC.L10N.register(
     "Appointment not found" : "Apwyntiad heb ei ganfod",
     "User not found" : "Defnyddiwr heb ei ganfod",
     "Hidden" : "Cudd",
+    "can edit" : "yn gallu golygu",
     "Automatic ({detected})" : "Awtomatig ({detected})",
     "Shortcut overview" : "Trosolwg llwybr byr",
+    "CalDAV link copied to clipboard." : "Dolen CalDAV wedi'i chopïo i'r clipfwrdd.",
+    "CalDAV link could not be copied to clipboard." : "Nid oedd modd copïo dolen CalDAV i'r clipfwrdd.",
+    "Enable birthday calendar" : "Galluogi calendr pen-blwydd",
+    "Show tasks in calendar" : "Dangos tasgau yn y calendr",
     "Enable simplified editor" : "Galluogi golygydd symlach",
+    "Show weekends" : "Dangos penwythnosau",
+    "Show week numbers" : "Dangos rhifau wythnosau",
     "Time increments" : "Cynyddiadau amser",
-    "Show keyboard shortcuts" : "Dangos llwybrau byr bysellfwrdd"
+    "Copy primary CalDAV address" : "Copïo prig gyfeiriad CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Copïo cyfeiriad CalDAV iOS/macOS",
+    "Personal availability settings" : "Gosodiadau argaeledd personol",
+    "Show keyboard shortcuts" : "Dangos llwybrau byr bysellfwrdd",
+    "Successfully appended link to talk room to description." : "Llwyddwyd i atodi dolen i'r ystafell siarad i'r disgrifiad.",
+    "Error creating Talk room" : "Gwall wrth greu ystafell Siarad",
+    "The visibility of this event in shared calendars." : "Gwelededd y digwyddiad hwn mewn calendrau a rennir.",
+    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
