@@ -128,7 +128,6 @@ OC.L10N.register(
     "Deleting share link …" : "מחיקת קישור השיתוף…",
     "An error occurred while unsharing the calendar." : "אירעה שגיאה במהלך ביטול שיתוף לוח השנה",
     "An error occurred, unable to change the permission of the share." : "אירעה שגיאה, לא ניתן לשנות את הרשאות השיתוף.",
-    "can edit" : "ניתן לערוך",
     "Unshare with {displayName}" : "ביטול שיתוף עם {displayName}",
     "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
     "No users or groups" : "אין משתמשים או קבוצות",
@@ -143,6 +142,7 @@ OC.L10N.register(
     "Calendar to import into" : "לוח שנה לייבוא אליו",
     "Cancel" : "ביטול",
     "_Import calendar_::_Import calendars_" : ["יבוא לוחות שנה","יבוא לוחות שנה","יבוא לוחות שנה"],
+    "Attachments folder" : "תיקיית הקבצים המצורפים",
     "{filename} could not be parsed" : "לא ניתן לפענח את {filename}",
     "No valid files found, aborting import" : "לא נמצאו קבצים תקפים, הייבוא מבוטל",
     "Import partially failed. Imported {accepted} out of {total}." : "הייבוא נכשל חלקית. מיובא {accepted} מתוך {total}.",
@@ -163,16 +163,9 @@ OC.L10N.register(
     "Show shortcuts" : "הצגת קיצורי דרך",
     "or" : "או",
     "No reminder" : "אין תזכורת",
-    "CalDAV link copied to clipboard." : "קישור ה־CalDAV הועתק ללוח הגזירים.",
-    "CalDAV link could not be copied to clipboard." : "לא ניתן להעתיק את קישור ה־CalDAV ללוח הגזירים.",
     "General" : "כללי",
-    "Copy primary CalDAV address" : "העתקת כתובת CalDAV עיקרית",
-    "Copy iOS/macOS CalDAV address" : "העתקת כתובת CalDAV ל־iOS/macOS",
-    "Enable birthday calendar" : "אפשר לוח שנה ליום הולדת ",
-    "Show tasks in calendar" : "הצג משימות בלוח השנה",
-    "Show weekends" : "הצגת סופי שבוע",
-    "Show week numbers" : "הצגת מספרי שבועות",
-    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Appearance" : "מראה",
+    "Files" : "קבצים",
     "Update" : "עדכון",
     "Location" : "מיקום",
     "Description" : "תיאור",
@@ -224,8 +217,6 @@ OC.L10N.register(
     "Decline" : "דחייה",
     "Tentative" : "טנטטיבית",
     "No attendees yet" : "עדיין אין משתתפים",
-    "Successfully appended link to talk room to description." : "הקישור צורף ל\"חדר השיחות\" לתיאור בהצלחה.",
-    "Error creating Talk room" : "שגיאה ביצירת \"חדר השיחות\"",
     "Attendees" : "משתתפים",
     "Remove group" : "הסרת קבוצה",
     "Remove attendee" : "הסר את המשתתף",
@@ -354,7 +345,6 @@ OC.L10N.register(
     "When shared show full event" : "כאשר משותף מציג אירוע מלא",
     "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
     "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
-    "The visibility of this event in shared calendars." : "הנראות של אירוע זה בלוחות שנה משותפים.",
     "Add a location" : "הוסף מיקום",
     "Status" : "מצב",
     "Confirmed" : "מאושר",
@@ -373,10 +363,23 @@ OC.L10N.register(
     "Imported {filename}" : "יובא {filename} ",
     "User not found" : "המשתמש לא נמצא",
     "Hidden" : "מוסתר",
+    "can edit" : "ניתן לערוך",
     "Calendar name …" : "שם לוח השנה ...",
     "Automatic ({detected})" : "אוטומטי ({detected})",
     "Shortcut overview" : "סקירת קיצור דרך",
+    "CalDAV link copied to clipboard." : "קישור ה־CalDAV הועתק ללוח הגזירים.",
+    "CalDAV link could not be copied to clipboard." : "לא ניתן להעתיק את קישור ה־CalDAV ללוח הגזירים.",
+    "Enable birthday calendar" : "אפשר לוח שנה ליום הולדת ",
+    "Show tasks in calendar" : "הצג משימות בלוח השנה",
     "Enable simplified editor" : "אפשר עורך פשוט",
-    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת"
+    "Show weekends" : "הצגת סופי שבוע",
+    "Show week numbers" : "הצגת מספרי שבועות",
+    "Copy primary CalDAV address" : "העתקת כתובת CalDAV עיקרית",
+    "Copy iOS/macOS CalDAV address" : "העתקת כתובת CalDAV ל־iOS/macOS",
+    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת",
+    "Successfully appended link to talk room to description." : "הקישור צורף ל\"חדר השיחות\" לתיאור בהצלחה.",
+    "Error creating Talk room" : "שגיאה ביצירת \"חדר השיחות\"",
+    "The visibility of this event in shared calendars." : "הנראות של אירוע זה בלוחות שנה משותפים.",
+    "Keyboard shortcuts" : "קיצורי מקלדת"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
