@@ -133,7 +133,6 @@ OC.L10N.register(
     "Deleting share link …" : "Deleting share link …",
     "An error occurred while unsharing the calendar." : "An error occurred while unsharing the calendar.",
     "An error occurred, unable to change the permission of the share." : "An error occurred, unable to change the permission of the share.",
-    "can edit" : "can edit",
     "Unshare with {displayName}" : "Unshare with {displayName}",
     "Share with users or groups" : "Share with users or groups",
     "No users or groups" : "No users or groups",
@@ -152,7 +151,7 @@ OC.L10N.register(
     "Invalid location selected" : "Invalid location selected",
     "Attachments folder successfully saved." : "Attachments folder successfully saved.",
     "Error on saving attachments folder." : "Error on saving attachments folder.",
-    "Default attachments location" : "Default attachments location",
+    "Attachments folder" : "Attachments folder",
     "{filename} could not be parsed" : "{filename} could not be parsed",
     "No valid files found, aborting import" : "No valid files found, aborting import",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Successfully imported %n event","Successfully imported %n events"],
@@ -180,19 +179,9 @@ OC.L10N.register(
     "or" : "or",
     "Calendar settings" : "Calendar settings",
     "No reminder" : "No reminder",
-    "CalDAV link copied to clipboard." : "CalDAV link copied to clipboard.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV link could not be copied to clipboard.",
     "General" : "General",
-    "Personal availability settings" : "Personal availability settings",
-    "Copy primary CalDAV address" : "Copy primary CalDAV address",
-    "Copy iOS/macOS CalDAV address" : "Copy iOS/macOS CalDAV address",
-    "Enable birthday calendar" : "Enable birthday calendar",
-    "Show tasks in calendar" : "Show tasks in calendar",
-    "Show weekends" : "Show weekends",
-    "Show week numbers" : "Show week numbers",
     "Editing" : "Editing",
     "Default reminder" : "Default reminder",
-    "Keyboard shortcuts" : "Keyboard shortcuts",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes"],
     "0 minutes" : "0 minutes",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} hours"],
@@ -297,9 +286,6 @@ OC.L10N.register(
     "Decline" : "Decline",
     "Tentative" : "Tentative",
     "No attendees yet" : "No attendees yet",
-    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
-    "Successfully appended link to talk room to description." : "Successfully appended link to talk room to description.",
-    "Error creating Talk room" : "Error creating Talk room",
     "Attendees" : "Attendees",
     "Remove group" : "Remove group",
     "Remove attendee" : "Remove attendee",
@@ -488,7 +474,6 @@ OC.L10N.register(
     "When shared show full event" : "When shared show full event",
     "When shared show only busy" : "When shared show only busy",
     "When shared hide this event" : "When shared hide this event",
-    "The visibility of this event in shared calendars." : "The visibility of this event in shared calendars.",
     "Add a location" : "Add a location",
     "Status" : "Status",
     "Confirmed" : "Confirmed",
@@ -512,12 +497,28 @@ OC.L10N.register(
     "Appointment not found" : "Appointment not found",
     "User not found" : "User not found",
     "Hidden" : "Hidden",
+    "can edit" : "can edit",
     "Calendar name …" : "Calendar name …",
+    "Default attachments location" : "Default attachments location",
     "Automatic ({detected})" : "Automatic ({detected})",
     "Shortcut overview" : "Shortcut overview",
+    "CalDAV link copied to clipboard." : "CalDAV link copied to clipboard.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV link could not be copied to clipboard.",
+    "Enable birthday calendar" : "Enable birthday calendar",
+    "Show tasks in calendar" : "Show tasks in calendar",
     "Enable simplified editor" : "Enable simplified editor",
     "Limit the number of events displayed in the monthly view" : "Limit the number of events displayed in the monthly view",
+    "Show weekends" : "Show weekends",
+    "Show week numbers" : "Show week numbers",
     "Time increments" : "Time increments",
-    "Show keyboard shortcuts" : "Show keyboard shortcuts"
+    "Copy primary CalDAV address" : "Copy primary CalDAV address",
+    "Copy iOS/macOS CalDAV address" : "Copy iOS/macOS CalDAV address",
+    "Personal availability settings" : "Personal availability settings",
+    "Show keyboard shortcuts" : "Show keyboard shortcuts",
+    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
+    "Successfully appended link to talk room to description." : "Successfully appended link to talk room to description.",
+    "Error creating Talk room" : "Error creating Talk room",
+    "The visibility of this event in shared calendars." : "The visibility of this event in shared calendars.",
+    "Keyboard shortcuts" : "Keyboard shortcuts"
 },
 "nplurals=2; plural=(n!=1);");
