@@ -190,15 +190,11 @@ OC.L10N.register(
     "At event start" : "Bij start gebeurtenis",
     "No reminder" : "Geen herinnering",
     "Failed to save default calendar" : "Kon standaardagenda niet opslaan",
-    "CalDAV link copied to clipboard." : "CalDAV link gekopiëerd naar klembord.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV link kon niet worden gekopieerd naar klembord.",
     "General" : "Algemeen",
-    "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
     "Appearance" : "Uiterlijk",
     "Editing" : "Bewerken",
-    "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
     "Default reminder" : "Standaard herinnering",
-    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
+    "Files" : "Bestanden",
     "Appointment schedule successfully created" : "Afspraakschema succesvol aangemaakt",
     "Appointment schedule successfully updated" : "Afspraakschema succesvol aangepast",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuut","{duration} minuten"],
@@ -326,9 +322,6 @@ OC.L10N.register(
     "Decline" : "Afwijzen",
     "Tentative" : "Voorlopig",
     "No attendees yet" : "Nog geen deelnemers",
-    "Successfully appended link to talk room to location." : "Succesvol de link naar de Talk ruimte aan de locatie toegevoegd.",
-    "Successfully appended link to talk room to description." : "Met succes een link naar de gespreksruimte toegevoegd aan de beschrijving.",
-    "Error creating Talk room" : "Fout tijdens aanmaken gespreksruimte",
     "Attendees" : "Deelnemers",
     "Remove group" : "Groep verwijderen",
     "Remove attendee" : "Verwijder genodigde",
@@ -555,6 +548,8 @@ OC.L10N.register(
     "Default attachments location" : "Standaard bijlagenlocatie",
     "Automatic ({detected})" : "Automatisch ({detected})",
     "Shortcut overview" : "Snelkoppeling overzicht",
+    "CalDAV link copied to clipboard." : "CalDAV link gekopiëerd naar klembord.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV link kon niet worden gekopieerd naar klembord.",
     "Enable birthday calendar" : "Verjaardagskalender inschakelen",
     "Show tasks in calendar" : "Toon taken in agenda",
     "Enable simplified editor" : "Eenvoudige editor inschakelen",
@@ -562,10 +557,16 @@ OC.L10N.register(
     "Show weekends" : "Toon weekenden",
     "Show week numbers" : "Tonen weeknummers",
     "Time increments" : "Time-toename",
+    "Default calendar for incoming invitations" : "Standaardagenda voor inkomende uitnodigingen",
     "Copy primary CalDAV address" : "Kopieer primair CalDAV adres",
+    "Copy iOS/macOS CalDAV address" : "Kopieer iOS/macOS CalDAV adres",
     "Personal availability settings" : "Persoonlijke beschikbaarheidsinstellingen",
     "Show keyboard shortcuts" : "Toon sneltoetsen",
     "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uitgenodigd, {confirmedCount} bevestigd",
-    "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's."
+    "Successfully appended link to talk room to location." : "Succesvol de link naar de Talk ruimte aan de locatie toegevoegd.",
+    "Successfully appended link to talk room to description." : "Met succes een link naar de gespreksruimte toegevoegd aan de beschrijving.",
+    "Error creating Talk room" : "Fout tijdens aanmaken gespreksruimte",
+    "The visibility of this event in shared calendars." : "De zichtbaarheid van deze afspraak in gedeelde agenda's.",
+    "Keyboard shortcuts" : "Toetsenbord sneltoetsen"
 },
 "nplurals=2; plural=(n != 1);");
