@@ -125,12 +125,9 @@ OC.L10N.register(
     "Show shortcuts" : "Mustra curtziadòrgios",
     "or" : "o",
     "No reminder" : "Perunu promemòria",
-    "CalDAV link copied to clipboard." : "Ligòngiu CalDAV copiadu in punta de billete.",
-    "CalDAV link could not be copied to clipboard." : "No at fatu a copiare su ligòngiu CalDAV in punta de billete.",
-    "Copy iOS/macOS CalDAV address" : "Còpia s'indiritzu CalDAV iOS/macOS",
     "Appearance" : "Aspetu",
     "Default reminder" : "Promemòria predefinidu",
-    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
+    "Files" : "Archìvios",
     "Update" : "Agiorna",
     "Location" : "Positzione",
     "Description" : "Descritzione",
@@ -185,8 +182,6 @@ OC.L10N.register(
     "Decline" : "Refuda",
     "Tentative" : "Intentu",
     "No attendees yet" : "Ancora peruna persone pro partetzipare",
-    "Successfully appended link to talk room to description." : "Ligòngiu apicadu in manera curreta in sa descritzione de s'aposentu de cunversatzione",
-    "Error creating Talk room" : "Errore in sa creatzione de s'aposentu Talk",
     "Attendees" : "Partetzipantes",
     "Remove group" : "Boga·nche grupu",
     "Remove attendee" : "Boga•nche partetzipante",
@@ -351,6 +346,8 @@ OC.L10N.register(
     "can edit" : "podet modificare",
     "Automatic ({detected})" : "Automàticu ({detected})",
     "Shortcut overview" : "Bista generale de is curtziadòrgiu",
+    "CalDAV link copied to clipboard." : "Ligòngiu CalDAV copiadu in punta de billete.",
+    "CalDAV link could not be copied to clipboard." : "No at fatu a copiare su ligòngiu CalDAV in punta de billete.",
     "Enable birthday calendar" : "Ativa su calendàriu de cumpleannos",
     "Show tasks in calendar" : "Mustra atividades in su calendàriu",
     "Enable simplified editor" : "Ativa s'editore semplificadu",
@@ -358,7 +355,11 @@ OC.L10N.register(
     "Show week numbers" : "Mustra nùmeru de chidas",
     "Time increments" : "Crèschidas de tempus",
     "Copy primary CalDAV address" : "Còpia s'indiritzu CalDAV printzipale",
+    "Copy iOS/macOS CalDAV address" : "Còpia s'indiritzu CalDAV iOS/macOS",
     "Show keyboard shortcuts" : "Mustra curtziadòrgios de tecladu",
-    "The visibility of this event in shared calendars." : "Sa visibilidade de custu eventu in is calendàrios cumpartzidos"
+    "Successfully appended link to talk room to description." : "Ligòngiu apicadu in manera curreta in sa descritzione de s'aposentu de cunversatzione",
+    "Error creating Talk room" : "Errore in sa creatzione de s'aposentu Talk",
+    "The visibility of this event in shared calendars." : "Sa visibilidade de custu eventu in is calendàrios cumpartzidos",
+    "Keyboard shortcuts" : "Curtziadòrgios de tecladu"
 },
 "nplurals=2; plural=(n != 1);");
