@@ -38,6 +38,8 @@ OC.L10N.register(
     "You will receive a link with the confirmation email" : "Prejeli boste elektronsko sporočilo z overitveno povezavo",
     "Where:" : "Kje:",
     "Comment:" : "Opomba",
+    "Location:" : "Mesto:",
+    "Duration:" : "Trajanje:",
     "A Calendar app for Nextcloud" : "Program za urejanje koledarja Nextcloud",
     "Previous day" : "Predhodni dan",
     "Previous week" : "Predhodni teden",
@@ -110,7 +112,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Ni mogoče posodobiti koledarja",
     "Shared calendars" : "Koledarji v souporabi",
     "Deck" : "Deck",
-    "Hidden" : "Skrito",
     "Internal link" : "Notranja povezava",
     "A private link that can be used with external clients" : "Zasebna povezava, ki se lahko uporablja z zunanjimi odjemalci",
     "Copy internal link" : "Kopiraj krajevno povezavo",
@@ -133,15 +134,15 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (Skupina)",
     "An error occurred while unsharing the calendar." : "Prišlo je do napake med onemogočanjem souporabe koledarja.",
     "An error occurred, unable to change the permission of the share." : "Prišlo je do napake; ni mogoče spremeniti dovoljenj souporabe.",
-    "can edit" : "lahko ureja",
     "Unshare with {displayName}" : "Odstrani souporabo z uporabnikom {displayName}",
     "Share with users or groups" : "Souporaba z uporabniki in skupinami",
     "No users or groups" : "Ni uporabnikov ali skupin",
     "Failed to save calendar name and color" : "Shranjevanje imena koledarja in barve je spodletelo",
-    "Calendar name …" : "Ime koledarja …",
     "Share calendar" : "Omogoči souporabo koledarja",
     "Unshare from me" : "Prekini souporabo",
     "Save" : "Shrani",
+    "No title" : "Ni naslova",
+    "View" : "Pogled",
     "Import calendars" : "Uvozi koledarje",
     "Please select a calendar to import into …" : "Izberite koledar za uvoz ...",
     "Filename" : "Ime datoteke",
@@ -153,14 +154,15 @@ OC.L10N.register(
     "Invalid location selected" : "Izbrano je neveljavno mesto",
     "Attachments folder successfully saved." : "Mapa prilog je uspešno shranjena.",
     "Error on saving attachments folder." : "Napaka med shranjevanjem mape prilog",
-    "Default attachments location" : "Privzeto mesto prilog",
+    "Attachments folder" : "Mapa prilog",
     "{filename} could not be parsed" : "Datoteke {filename} ni mogoče razčleniti",
     "No valid files found, aborting import" : "Ni najdenih veljavnih datotek, uvoz bo preklican",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Uspešno je uvožen %n dogodek.","Uspešno sta uvožena %n dogodka.","Uspešno so uvoženi %n dogodki.","Uspešno je uvoženih %n dogodkov."],
     "Import partially failed. Imported {accepted} out of {total}." : "Uvoz je delno spodletel. Uvoženih je {accepted} od skupno {total}.",
     "Automatic" : "Samodejno",
-    "Automatic ({detected})" : "Samodejno ({detected})",
+    "Automatic ({timezone})" : "Samodejno ({timezone})",
     "New setting was not saved successfully." : "Novih nastavitev ni bilo mogoče shraniti.",
+    "Timezone" : "Časovni pas",
     "Navigation" : "Krmarjenje",
     "Previous period" : "Predhodno obdobje",
     "Next period" : "Naslednje obdobje",
@@ -178,26 +180,15 @@ OC.L10N.register(
     "Save edited event" : "Shrani spremenjen dogodek",
     "Delete edited event" : "Izbriši spremenjen dogodek",
     "Duplicate event" : "Podvoji dogodek",
-    "Shortcut overview" : "Pregled tipkovnih bližnjic",
     "or" : "ali",
     "Calendar settings" : "Nastavitve koledarja",
     "No reminder" : "Brez opomnika",
     "Failed to save default calendar" : "Shranjevanje privzetega koledarja je spodletelo",
-    "CalDAV link copied to clipboard." : "Povezava CalDAV je kopirana v odložišče.",
-    "CalDAV link could not be copied to clipboard." : "Povezave CalDAV ni mogoče kopirati v odložišče.",
-    "Enable birthday calendar" : "Omogoči koledar rojstnih dni",
-    "Show tasks in calendar" : "Pokaži naloge v koledarju",
-    "Enable simplified editor" : "Omogoči poenostavljen urejevalnik",
-    "Limit the number of events displayed in the monthly view" : "Omeji število dogodkov v pogledu meseca",
-    "Show weekends" : "Pokaži vikende",
-    "Show week numbers" : "Pokaži številke tednov",
-    "Time increments" : "Časovno povečevanje",
-    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
+    "General" : "Splošno",
+    "Appearance" : "Videz",
+    "Editing" : "Urejanje",
     "Default reminder" : "Privzeti opomnik",
-    "Copy primary CalDAV address" : "Kopiraj osnovni naslov CalDAV",
-    "Copy iOS/macOS CalDAV address" : "Kopiraj naslov CalDAV za iOS/macOS",
-    "Personal availability settings" : "Nastavitve osebne dejavnosti",
-    "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice",
+    "Files" : "Datoteke",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuta","{duration} minuti","{duration} minute","{duration} minut"],
     "0 minutes" : "0 minut",
     "_{duration} hour_::_{duration} hours_" : ["{duration} ura","{duration} uri","{duration} ure","{duration} ur"],
@@ -245,11 +236,9 @@ OC.L10N.register(
     "Please share anything that will help prepare for our meeting" : "Pošljite vse predloge in dokumente, ki so pomembni pri pripravi na srečanje.",
     "Could not book the appointment. Please try again later or contact the organizer." : "Sestanka ni mogoče rezervirati. Poskusite znova kasneje oziroma stopite v stik z organizatorjem.",
     "Back" : "Nazaj",
-    "Create a new conversation" : "Ustvari nov pogovor",
     "Select conversation" : "pogovora",
     "on" : "na",
     "at" : "ob",
-    "Reminder" : "Opomnik",
     "before at" : "prej ob",
     "Notification" : "Obvestilo",
     "Email" : "Elektronsko sporočilo",
@@ -260,7 +249,6 @@ OC.L10N.register(
     "Edit time" : "Uredi čas",
     "Save time" : "Shrani čas",
     "Remove reminder" : "Odstrani opomnik",
-    "+ Add reminder" : "+ Dodaj opomnik",
     "Add reminder" : "Dodaj opomnik",
     "seconds" : "sekunde",
     "minutes" : "minute",
@@ -295,17 +283,17 @@ OC.L10N.register(
     "non-participant" : "neudeleženec",
     "optional participant" : "udeleženec na željo",
     "{organizer} (organizer)" : "{organizer} (organizator)",
+    "Availability of attendees, resources and rooms" : "Razpoložljivost udeležencev, virov in sob",
+    "Suggestion accepted" : "Predlog je sprejet",
+    "Legend" : "Legenda",
+    "Out of office" : "Službena odsotnost",
+    "Attendees:" : "Udeleženci:",
+    "Done" : "Končano",
+    "Room name" : "Ime sobe",
     "Free" : "Prosto",
     "Busy (tentative)" : "Načrtovano delo",
     "Busy" : "Zasedeno",
-    "Out of office" : "Službena odsotnost",
     "Unknown" : "Neopredeljeno",
-    "Availability of attendees, resources and rooms" : "Razpoložljivost udeležencev, virov in sob",
-    "with" : "z",
-    "Available times:" : "Razpoložljivi termini",
-    "Suggestion accepted" : "Predlog je sprejet",
-    "Done" : "Končano",
-    "Room name" : "Ime sobe",
     "Find a time" : "Najdi čas",
     "The invitation has been accepted successfully." : "Vabilo je uspešno sprejeto.",
     "Failed to accept the invitation." : "Sprejemanje povabila je spodletelo.",
@@ -317,8 +305,6 @@ OC.L10N.register(
     "Decline" : "Zavrni",
     "Tentative" : "V usklajevanju",
     "No attendees yet" : "Ni še vpisanih udeležencev",
-    "Successfully appended link to talk room to description." : "Povezava do sobe Talk je uspešno dodana v opis.",
-    "Error creating Talk room" : "Prišlo je do napake med ustvarjanjem klepetalnice Talk",
     "Attendees" : "Udeleženci",
     "Remove group" : "Odstrani skupino",
     "Remove attendee" : "Odstrani udeleženca",
@@ -335,7 +321,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Ni mogoče spremeniti nastavitve »celodnevno« za dogodke, ki so opredeljeni kot ponavljajoči.",
     "From" : "Od",
     "To" : "Za",
-    "All day" : "Ves dan",
     "Repeat" : "Ponovi",
     "_time_::_times_" : [" ponovitvi"," ponovitvah"," ponovitvah"," ponovitvah"],
     "never" : "nikoli",
@@ -358,7 +343,7 @@ OC.L10N.register(
     "Does not repeat" : "Se ne ponavlja",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Določilo ponavljanja tega dogodka ni v celoti podprto! Z urejanjem možnosti ponavljanja so lahko nekatera določila prepisana.",
     "No rooms or resources yet" : "Ni še določenih sob ali virov",
-    "Suggestions" : "Predlogi",
+    "Resources" : "Viri",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} sedež","{seatingCapacity} sedeža","{seatingCapacity} sedeži","{seatingCapacity} sedežev"],
     "Add resource" : "Dodaj vir",
     "Has a projector" : "Na voljo je projektor",
@@ -378,6 +363,12 @@ OC.L10N.register(
     "Update this occurrence" : "Posodobi to pojavitev",
     "Public calendar does not exist" : "Javni koledar ne obstaja",
     "Maybe the share was deleted or has expired?" : "Morda je mesto souporabe izbrisano ali je časovno poteklo.",
+    "Remove participant" : "Odstrani udeležence",
+    "Yes" : "Da",
+    "No" : "Ne",
+    "Maybe" : "Morda",
+    "None" : "Brez",
+    "Create" : "Ustvari",
     "from {formattedDate}" : "od {formattedDate}",
     "to {formattedDate}" : "do {formattedDate}",
     "on {formattedDate}" : "na {formattedDate}",
@@ -419,17 +410,22 @@ OC.L10N.register(
     "Personal" : "Osebno",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Samodejno zaznavanje časovnega pasu določa časovni pas kot UTC.\nTo je najverjetneje prilagojeno na varnostne nastavitve spletnega brskalnika.\nČasovni pas lahko določite tudi ročno med nastavitvami koledarja.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Nastavljenega časovnega pasu ({timezoneId}) ni mogoče najti. Povrnjena bo nastavitev na UTC.\nČasovni pas določite ročno med nastavitvami koledarja in pošljite poročilo o napaki.",
+    "Edit event" : "Uredi dogodek",
     "Event does not exist" : "Dogodek ne obstaja",
     "Duplicate" : "Podvoji",
     "Delete this occurrence" : "Izbriši to pojavitev",
     "Delete this and all future" : "Izbriši to in vse prihodnje pojavitve",
-    "Details" : "Podrobnosti",
+    "All day" : "Ves dan",
     "Managing shared access" : "Upravljanje z dostopom",
     "Deny access" : "Zavrni dostop",
     "Invite" : "Povabi",
-    "Resources" : "Viri",
     "Untitled event" : "Neimenovan dogodek",
     "Close" : "Zapri",
+    "Selected" : "Izbrano",
+    "Title" : "Naslov",
+    "30 min" : "30 min",
+    "Participants" : "Udeleženci",
+    "Submit" : "Pošlji",
     "Subscribe to {name}" : "Naroči na {name}",
     "Export {name}" : "Izvozi {name}",
     "Anniversary" : "Obletnica",
@@ -497,7 +493,6 @@ OC.L10N.register(
     "When shared show full event" : "V souporabi pokaži poln dogodek",
     "When shared show only busy" : "V souporabi pokaži le, da je zasedeno",
     "When shared hide this event" : "V souporabi skrij ta dogodek",
-    "The visibility of this event in shared calendars." : "Vidnost tega dogodka v koledarjih v souporabi.",
     "Add a location" : "Dodaj mesto ...",
     "Status" : "Stanje",
     "Confirmed" : "Potrjeno",
@@ -519,6 +514,30 @@ OC.L10N.register(
     "Imported {filename}" : "Uvožena datoteka {filename}",
     "This is an event reminder." : "To je opomnik dogodka.",
     "Appointment not found" : "Sestanka ni mogoče najti",
-    "User not found" : "Uporabnika ni mogoče najti"
+    "User not found" : "Uporabnika ni mogoče najti",
+    "Hidden" : "Skrito",
+    "can edit" : "lahko ureja",
+    "Calendar name …" : "Ime koledarja …",
+    "Default attachments location" : "Privzeto mesto prilog",
+    "Automatic ({detected})" : "Samodejno ({detected})",
+    "Shortcut overview" : "Pregled tipkovnih bližnjic",
+    "CalDAV link copied to clipboard." : "Povezava CalDAV je kopirana v odložišče.",
+    "CalDAV link could not be copied to clipboard." : "Povezave CalDAV ni mogoče kopirati v odložišče.",
+    "Enable birthday calendar" : "Omogoči koledar rojstnih dni",
+    "Show tasks in calendar" : "Pokaži naloge v koledarju",
+    "Enable simplified editor" : "Omogoči poenostavljen urejevalnik",
+    "Limit the number of events displayed in the monthly view" : "Omeji število dogodkov v pogledu meseca",
+    "Show weekends" : "Pokaži vikende",
+    "Show week numbers" : "Pokaži številke tednov",
+    "Time increments" : "Časovno povečevanje",
+    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
+    "Copy primary CalDAV address" : "Kopiraj osnovni naslov CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Kopiraj naslov CalDAV za iOS/macOS",
+    "Personal availability settings" : "Nastavitve osebne dejavnosti",
+    "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice",
+    "Successfully appended link to talk room to description." : "Povezava do sobe Talk je uspešno dodana v opis.",
+    "Error creating Talk room" : "Prišlo je do napake med ustvarjanjem klepetalnice Talk",
+    "The visibility of this event in shared calendars." : "Vidnost tega dogodka v koledarjih v souporabi.",
+    "Keyboard shortcuts" : "Tipkovne bližnjice"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
